﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Optimization;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Analysis.AlgorithmBehavior.Analyzers {
  [Item("DataTableHelper", "Helper class for creating datatables.")]
  [StorableClass]
  public class DataTableHelper : Item {

    [Storable]
    private ResultCollection resultsCol;
    [Storable]
    private string chartName;
    [Storable]
    private string dataRowName;
    [Storable]
    private DataRow dtRow;

    [StorableConstructor]
    private DataTableHelper(bool deserializing) : base(deserializing) { }
    private DataTableHelper(DataTableHelper original, Cloner cloner)
      : base(original, cloner) { }
    public DataTableHelper() : base() { }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new DataTableHelper(this, cloner);
    }

    public void InitializeChart(ResultCollection results, string chartName, string dataRowName) {
      if (!results.ContainsKey(chartName)) {
        this.resultsCol = results;
        this.chartName = chartName;
        this.dataRowName = dataRowName;

        DataTable dt = new DataTable(chartName);
        dtRow = new DataRow(dataRowName);
        dt.Rows.Add(dtRow);
        results.Add(new Result(chartName, dt));
      }
    }

    public void AddPoint(double point) {
      dtRow.Values.Add(point);
    }
  }
}
